package gregapi.render;

import gregapi.old.Dyes;
import gregapi.old.interfaces.IColorModulationContainer;
import net.minecraft.block.Block;
import net.minecraft.client.renderer.RenderBlocks;

/** 
 * @author Gregorius Techneticies
 */
public class BlockTextureSided implements ITexture, IColorModulationContainer {
	private final IIconContainer[] mIconContainer;
	
	/**
	 *  DO NOT MANIPULATE THE VALUES INSIDE THIS ARRAY!!!
	 *  
	 *  Just set this variable to another different Array instead.
	 *  Otherwise some colored things will get Problems.
	 */
	public short[] mRGBa;
	
	private final boolean mAllowAlpha;
	
	public BlockTextureSided(IIconContainer aIcon0, IIconContainer aIcon1, IIconContainer aIcon2, IIconContainer aIcon3, IIconContainer aIcon4, IIconContainer aIcon5, short[] aRGBa, boolean aAllowAlpha) {
		if (aRGBa.length != 4) throw new IllegalArgumentException("RGBa doesn't have 4 Values @ BlockTextureSided");
		mIconContainer = new IIconContainer[] {aIcon0, aIcon1, aIcon2, aIcon3, aIcon4, aIcon5};
		mAllowAlpha = aAllowAlpha;
		mRGBa = aRGBa;
	}
	
	public BlockTextureSided(IIconContainer aIcon0, IIconContainer aIcon1, IIconContainer aIcon2, IIconContainer aIcon3, IIconContainer aIcon4, IIconContainer aIcon5, short[] aRGBa) {
		this(aIcon0, aIcon1, aIcon2, aIcon3, aIcon4, aIcon5, aRGBa, true);
	}
	
	public BlockTextureSided(IIconContainer aIcon0, IIconContainer aIcon1, IIconContainer aIcon2, IIconContainer aIcon3, IIconContainer aIcon4, IIconContainer aIcon5) {
		this(aIcon0, aIcon1, aIcon2, aIcon3, aIcon4, aIcon5, Dyes._NULL.mRGBa);
	}
	
	public BlockTextureSided(IIconContainer aBottom, IIconContainer aTop, IIconContainer aSides, short[] aRGBa) {
		this(aBottom, aTop, aSides, aSides, aSides, aSides, aRGBa);
	}
	
	public BlockTextureSided(IIconContainer aBottom, IIconContainer aTop, IIconContainer aSides) {
		this(aBottom, aTop, aSides, Dyes._NULL.mRGBa);
	}
	
	@Override
	public void renderXPos(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderXPos(mIconContainer[5].getIcon(0), mRGBa, mAllowAlpha, aRenderer, aBlock, aX, aY, aZ, aBrightness);
	}
	
	@Override
	public void renderXNeg(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderXNeg(mIconContainer[4].getIcon(0), mRGBa, mAllowAlpha, aRenderer, aBlock, aX, aY, aZ, aBrightness);
	}
	
	@Override
	public void renderYPos(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderYPos(mIconContainer[1].getIcon(0), mRGBa, mAllowAlpha, aRenderer, aBlock, aX, aY, aZ, aBrightness);
	}
	
	@Override
	public void renderYNeg(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderZPos(mIconContainer[0].getIcon(0), mRGBa, mAllowAlpha, aRenderer, aBlock, aX, aY, aZ, aBrightness);
	}
	
	@Override
	public void renderZPos(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderZPos(mIconContainer[3].getIcon(0), mRGBa, mAllowAlpha, aRenderer, aBlock, aX, aY, aZ, aBrightness);
	}
	
	@Override
	public void renderZNeg(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
		ITexture.Util.renderZNeg(mIconContainer[2].getIcon(0), mRGBa, mAllowAlpha, aRenderer, aBlock, aX, aY, aZ, aBrightness);
	}
	
	@Override
	public short[] getRGBA() {
		return mRGBa;
	}
	
	@Override
	public boolean isValidTexture() {
		return mIconContainer != null && mIconContainer[0] != null && mIconContainer[1] != null && mIconContainer[2] != null && mIconContainer[3] != null && mIconContainer[4] != null && mIconContainer[5] != null;
	}
}